]> git.tdb.fi Git - ext/subsurface.git/blobdiff - dive.h
Start "output unit management" support
[ext/subsurface.git] / dive.h
diff --git a/dive.h b/dive.h
index 0bac6b2b9eeb580727c2c7cddbf6efc71f19e89f..ea8fceec1863dc41479d448912998f9a4156a642 100644 (file)
--- a/dive.h
+++ b/dive.h
@@ -1,6 +1,11 @@
 #ifndef DIVE_H
 #define DIVE_H
 
+#include <stdlib.h>
+#include <time.h>
+
+#include <glib.h>
+
 /*
  * Some silly typedefs to make our units very explicit.
  *
@@ -11,7 +16,7 @@
  *
  * We also strive to make '0' a meaningless number saying "not
  * initialized", since many values are things that may not have
* been reported (eg tank pressure or temperature from dive
  * computers that don't support them). But sometimes -1 is an even
  * more explicit way of saying "not there".
  *
@@ -19,7 +24,7 @@
  * temperatures. Doing temperatures in celsius or fahrenheit would
  * make for loss of precision when converting from one to the other,
  * and using millikelvin is SI-like but also means that a temperature
* of '0' is clearly just a missing temperature or tank pressure.
  *
  * Also strive to use units that can not possibly be mistaken for a
  * valid value in a "normal" system without conversion. If the max
@@ -66,14 +71,20 @@ typedef struct {
 
 typedef struct {
        fraction_t o2;
-       fraction_t n2;
        fraction_t he;
 } gasmix_t;
 
 typedef struct {
        volume_t size;
-       pressure_t pressure;
-} tank_type_t;
+       pressure_t workingpressure;
+       const char *description;        /* "LP85", "AL72", "AL80", "HP100+" or whatever */
+} cylinder_type_t;
+
+typedef struct {
+       cylinder_type_t type;
+       gasmix_t gasmix;
+       pressure_t start, end;
+} cylinder_t;
 
 static inline int to_feet(depth_t depth)
 {
@@ -96,25 +107,41 @@ struct sample {
        duration_t time;
        depth_t depth;
        temperature_t temperature;
-       pressure_t tankpressure;
-       int tankindex;
+       pressure_t cylinderpressure;
+       int cylinderindex;
 };
 
-#define MAX_MIXES (4)
+#define MAX_CYLINDERS (8)
 
 struct dive {
-       const char *name;
        time_t when;
+       char *location;
+       char *notes;
        depth_t maxdepth, meandepth;
        duration_t duration, surfacetime;
        depth_t visibility;
        temperature_t airtemp, watertemp;
-       pressure_t beginning_pressure, end_pressure;
-       gasmix_t gasmix[MAX_MIXES];
+       cylinder_t cylinder[MAX_CYLINDERS];
        int samples;
        struct sample sample[];
 };
 
+/*
+ * We keep our internal data in well-specified units, but
+ * the input and output may come in some random format. This
+ * keeps track of those units.
+ */
+struct units {
+       enum { METERS, FEET } length;
+       enum { LITER, CUFT } volume;
+       enum { BAR, PSI, PASCAL } pressure;
+       enum { CELSIUS, FAHRENHEIT, KELVIN } temperature;
+       enum { KG, LBS } weight;
+};
+
+extern const struct units SI_units, IMPERIAL_units;
+extern struct units input_units, output_units;
+
 extern int verbose;
 
 struct dive_table {
@@ -132,6 +159,19 @@ static inline struct dive *get_dive(unsigned int nr)
 }
 
 extern void parse_xml_init(void);
-extern void parse_xml_file(const char *filename);
+extern void parse_xml_file(const char *filename, GError **error);
+
+extern void flush_dive_info_changes(void);
+extern void save_dives(const char *filename);
+
+static inline unsigned int dive_size(int samples)
+{
+       return sizeof(struct dive) + samples*sizeof(struct sample);
+}
+
+extern struct dive *fixup_dive(struct dive *dive);
+extern struct dive *try_to_merge(struct dive *a, struct dive *b);
+
+#define DIVE_ERROR_PARSE 1
 
 #endif /* DIVE_H */
@@ -11,7 +16,7 @@
  * We also strive to make '0' a meaningless number saying "not
  * initialized", since many values are things that may not have
- * been reported (eg tank pressure or temperature from dive
+ * been reported (eg cylinder pressure or temperature from dive
  * computers that don't support them). But sometimes -1 is an even
  * more explicit way of saying "not there".
@@ -19,7 +24,7 @@
  * make for loss of precision when converting from one to the other,
  * and using millikelvin is SI-like but also means that a temperature
- * of '0' is clearly just a missing temperature or tank pressure.
+ * of '0' is clearly just a missing temperature or cylinder pressure.
  *
  * Also strive to use units that can not possibly be mistaken for a